==> vtigercrm-5.3.0p0.tgz: modules/Quotes/language/es_mx.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Quotes
*  Language     : Español
*  Version      : 504
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2008-09-20
*  Author       : Joe Bordes JPL TSolucio, S.L.
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Cotizaciones',
'LBL_MODULE_TITLE'=>'Cotizaciones: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Cotizaciones',
'LBL_LIST_FORM_TITLE'=>'Lista de Cotizaciones',
'LBL_NEW_FORM_TITLE'=>'Nueva Cotización',
'LBL_MEMBER_ORG_FORM_TITLE'=>'Organizaciones miembro',

'LBL_LIST_ACCOUNT_NAME'=>'Nombre de Cuenta',
'LBL_RELATED_PRODUCTS'=>'Productos',
'LBL_LIST_CITY'=>'Deleg./Mpio.',
'LBL_LIST_WEBSITE'=>'Página Web',
'LBL_LIST_STATE'=>'Estado',
'LBL_LIST_PHONE'=>'Teléfono',
'LBL_LIST_EMAIL_ADDRESS'=>'Dirección de Email',
'LBL_LIST_CONTACT_NAME'=>'Persona de Contacto',

//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_name' => 'LBL_LIST_ACCOUNT_NAME',
'db_website' => 'LBL_LIST_WEBSITE',
'db_billing_address_city' => 'LBL_LIST_CITY',

//END DON'T CONVERT

'LBL_ACCOUNT'=>'Cuenta:',
'LBL_PHONE'=>'Teléfono:',
'LBL_WEBSITE'=>'Página Web:',
'LBL_FAX'=>'Fax:',
'LBL_TICKER_SYMBOL'=>'Símbolo de bolsa:',
'LBL_OTHER_PHONE'=>'Tel. Directo:',
'LBL_ANY_PHONE'=>'Tel. Adicional:',
'LBL_MEMBER_OF'=>'Miembro de:',
'LBL_EMAIL'=>'Email:',
'LBL_EMPLOYEES'=>'Empleados:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Email (Otro):',
'LBL_ANY_EMAIL'=>'Email (Alternativo):',
'LBL_OWNERSHIP'=>'Propiedad:',
'LBL_RATING'=>'Valoración:',
'LBL_INDUSTRY'=>'Actividad:',
'LBL_SIC_CODE'=>'RFC:',
'LBL_TYPE'=>'Tipo:',
'LBL_ANNUAL_REVENUE'=>'Facturación Anual:',
'LBL_ADDRESS_INFORMATION'=>'Información de la Dirección',
'LBL_Quote_INFORMATION'=>'Información de la Cotización',
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',
'LBL_BILLING_ADDRESS'=>'Dirección (Factura):',
'LBL_SHIPPING_ADDRESS'=>'Dirección (Envío):',
'LBL_ANY_ADDRESS'=>'Dirección (Alternativa):',
'LBL_CITY'=>'Deleg./Mpio.:',
'LBL_STATE'=>'Estado:',
'LBL_POSTAL_CODE'=>'Código Postal:',
'LBL_COUNTRY'=>'País:',
'LBL_DESCRIPTION_INFORMATION'=>'Información Adicional',
'LBL_DESCRIPTION'=>'Descripción:',
'NTC_COPY_BILLING_ADDRESS'=>'Copiar Factura a Entvío',
'NTC_COPY_SHIPPING_ADDRESS'=>'Copiar Entvío a Factura',
'NTC_REMOVE_MEMBER_ORG_CONFIRMATION'=>'¿Está seguro que desea eliminar este expediente como Organización miembro?',
'LBL_DUPLICATE'=>'Posibles Cuentas Duplicadas',
'MSG_DUPLICATE' => 'Al dar de alta esta cuenta puede que se cree una cuenta duplicada. Puede seleccionar una cuenta del listado inferior o hacer click en Crear Nueva Cuenta para continuar creando la cuenta con los datos introducidos.',

'LBL_INVITEE'=>'Contactos',
'ERR_DELETE_RECORD'=>'Debe especificar un registro para eliminar la cuenta.',

'LBL_SELECT_ACCOUNT'=>'Seleccionar Cuenta',
'LBL_GENERAL_INFORMATION'=>'Información General',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nueva Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nueva Tarea',
'LBL_TASK_TITLE'=>'Tareas',
'LBL_NEW_CALL'=>'Nueva llamada',
'LBL_CALL_TITLE'=>'Llamadas',
'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',
'LBL_NEW_EMAIL'=>'Nuevo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_CONTACT'=>'Nuevo Contacto',
'LBL_CONTACT_TITLE'=>'Contactos',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'Todo',
'LBL_PROSPECT'=>'Investigador',
'LBL_INVESTOR'=>'Inversionista',
'LBL_RESELLER'=>'Revendedor ',
'LBL_PARTNER'=>'Socio',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Cuenta',
//Added for 4GA
'Subject'=>'Referencia',
'Potential Name'=>'Oportunidad',
'Quote Stage'=>'Estado de la Cotización',
'Valid Till'=>'Válido Hasta',
'Team'=>'Equipo',
'Contact Name'=>'Nombre de Contacto',
'Currency'=>'Moneda',
'Carrier'=>'Transportista',
'Sub Total'=>'Total',
'Shipping'=>'Envío',
'Inventory Manager'=>'Encargado del Inventario',
'Type'=>'Tipo',
'Tax'=>'Impuesto',
'Total'=>'Total',
'Product Name'=>'Nombre de Producto',
'Assigned To'=>'Asignado a',
'Billing Address'=>'Dirección (Factura)',
'Shipping Address'=>'Dirección (Envío)',
'Billing City'=>'Deleg./Mpio. (Factura)',
'Billing State'=>'Estado (Factura)',
'Billing Code'=>'Código Postal (Factura)',
'Billing Country'=>'País (Factura)',
'Billing Po Box'=>'Colonia (Factura)',
'Shipping Po Box'=>'Colonia (Envío)',
'Shipping City'=>'Deleg./Mpio. (Envío)',
'Shipping State'=>'Estado (Envío)',
'Shipping Code'=>'Código Postal (Envío)',
'Shipping Country'=>'País (Envío)',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Última Modificación',
'Description'=>'Descripción',
'Account Name'=>'Nombre de la Cuenta',
'Terms & Conditions'=>'Condiciones Generales',
//Quote Info
'LBL_QUOTE_INFORMATION'=>'Información de la Cotización',
'LBL_TERMS_INFORMATION'=>'Condiciones Generales',
'LBL_QUOTE'=>'Cotización:',

//Added during 4.2 release
'LBL_SUBJECT'=>'Referencia:',
'LBL_POTENTIAL_NAME'=>'Oportunidad:',
'LBL_ACCOUNT_NAME'=>'Nombre de la Cuenta:',
'LBL_QUOTE_STAGE'=>'Estado de la Cotización:',
'LBL_MY_TOP_QUOTE'=>'Mis Cotizaciones Pendientes',
//'Quote ID'=>'Id Cotización',
'Quote'=>'Cotización',

//Added for existing Picklist Entries

'Created'=>'Creado',
'Delivered'=>'Enviado',
'Reviewed'=>'Revisado',
'Accepted'=>'Aceptado',
'Rejected'=>'Rechazado',

'FedEx'=>'FedEx',
'UPS'=>'UPS',
'USPS'=>'Seur',
'DHL'=>'DHL',
'BlueDart'=>'Correos',
'Sales Tax'=>'Impuesto de Ventas',                 

//Added for Reports (5.0.4)
'Tax Type'=>'Impuesto',
'Discount Percent'=>'Descuento %',
'Discount Amount'=>'Descuento Importe',
'Terms & Conditions'=>'Condiciones Generales',
'Adjustment'=>'Ajustes',
'S&H Amount'=>'Importe Envío y Manipulado',

//Added after 5.0.4 GA
'Quote No'=>'No Cotización',
);

?>

==> vtigercrm-5.4.0.tgz: modules/Quotes/language/es_mx.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Quotes
*  Language     : Español
*  Version      : 5.4.0
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2012-02-27
*  Author       : Joe Bordes JPL TSolucio, S.L.
*  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Cotizaciones',
'SINGLE_Quotes'=>'Cotización',
'LBL_MODULE_TITLE'=>'Cotizaciones: Inicio',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Cotizaciones',
'LBL_LIST_FORM_TITLE'=>'Lista de Cotizaciones',
'LBL_NEW_FORM_TITLE'=>'Nueva Cotización',
'LBL_MEMBER_ORG_FORM_TITLE'=>'Organizaciones miembro',

'LBL_LIST_ACCOUNT_NAME'=>'Nombre de Cuenta',
'LBL_RELATED_PRODUCTS'=>'Productos',
'LBL_LIST_CITY'=>'Deleg./Mpio.',
'LBL_LIST_WEBSITE'=>'Página Web',
'LBL_LIST_STATE'=>'Estado',
'LBL_LIST_PHONE'=>'Teléfono',
'LBL_LIST_EMAIL_ADDRESS'=>'Dirección de Email',
'LBL_LIST_CONTACT_NAME'=>'Persona de Contacto',

//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_name' => 'LBL_LIST_ACCOUNT_NAME',
'db_website' => 'LBL_LIST_WEBSITE',
'db_billing_address_city' => 'LBL_LIST_CITY',

//END DON'T CONVERT

'LBL_ACCOUNT'=>'Cuenta:',
'LBL_PHONE'=>'Teléfono:',
'LBL_WEBSITE'=>'Página Web:',
'LBL_FAX'=>'Fax:',
'LBL_TICKER_SYMBOL'=>'Símbolo de bolsa:',
'LBL_OTHER_PHONE'=>'Tel. Directo:',
'LBL_ANY_PHONE'=>'Tel. Adicional:',
'LBL_MEMBER_OF'=>'Miembro de:',
'LBL_EMAIL'=>'Email:',
'LBL_EMPLOYEES'=>'Empleados:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Email (Otro):',
'LBL_ANY_EMAIL'=>'Email (Alternativo):',
'LBL_OWNERSHIP'=>'Propiedad:',
'LBL_RATING'=>'Valoración:',
'LBL_INDUSTRY'=>'Actividad:',
'LBL_SIC_CODE'=>'RFC:',
'LBL_TYPE'=>'Tipo:',
'LBL_ANNUAL_REVENUE'=>'Facturación Anual:',
'LBL_ADDRESS_INFORMATION'=>'Información de la Dirección',
'LBL_Quote_INFORMATION'=>'Información de la Cotización',
'LBL_CUSTOM_INFORMATION'=>'Información Personalizada',
'LBL_BILLING_ADDRESS'=>'Dirección (Factura):',
'LBL_SHIPPING_ADDRESS'=>'Dirección (Envío):',
'LBL_ANY_ADDRESS'=>'Dirección (Alternativa):',
'LBL_CITY'=>'Deleg./Mpio.:',
'LBL_STATE'=>'Estado:',
'LBL_POSTAL_CODE'=>'Código Postal:',
'LBL_COUNTRY'=>'País:',
'LBL_DESCRIPTION_INFORMATION'=>'Información Adicional',
'LBL_DESCRIPTION'=>'Descripción:',
'NTC_COPY_BILLING_ADDRESS'=>'Copiar Factura a Entvío',
'NTC_COPY_SHIPPING_ADDRESS'=>'Copiar Entvío a Factura',
'NTC_REMOVE_MEMBER_ORG_CONFIRMATION'=>'¿Está seguro que desea eliminar este expediente como Organización miembro?',
'LBL_DUPLICATE'=>'Posibles Cuentas Duplicadas',
'MSG_DUPLICATE' => 'Al dar de alta esta cuenta puede que se cree una cuenta duplicada. Puede seleccionar una cuenta del listado inferior o hacer click en Crear Nueva Cuenta para continuar creando la cuenta con los datos introducidos.',

'LBL_INVITEE'=>'Contactos',
'ERR_DELETE_RECORD'=>'Debe especificar un registro para eliminar la cuenta.',

'LBL_SELECT_ACCOUNT'=>'Seleccionar Cuenta',
'LBL_GENERAL_INFORMATION'=>'Información General',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nueva Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nueva Tarea',
'LBL_TASK_TITLE'=>'Tareas',
'LBL_NEW_CALL'=>'Nueva llamada',
'LBL_CALL_TITLE'=>'Llamadas',
'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',
'LBL_NEW_EMAIL'=>'Nuevo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_CONTACT'=>'Nuevo Contacto',
'LBL_CONTACT_TITLE'=>'Contactos',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'Todo',
'LBL_PROSPECT'=>'Investigador',
'LBL_INVESTOR'=>'Inversionista',
'LBL_RESELLER'=>'Revendedor ',
'LBL_PARTNER'=>'Socio',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Cuenta',
//Added for 4GA
'Subject'=>'Referencia',
'Potential Name'=>'Oportunidad',
'Quote Stage'=>'Estado de la Cotización',
'Valid Till'=>'Válido Hasta',
'Team'=>'Equipo',
'Contact Name'=>'Nombre de Contacto',
'Currency'=>'Moneda',
'Carrier'=>'Transportista',
'Sub Total'=>'Total',
'Shipping'=>'Envío',
'Inventory Manager'=>'Encargado del Inventario',
'Type'=>'Tipo',
'Tax'=>'Impuesto',
'Total'=>'Total',
'Product Name'=>'Nombre de Producto',
'Assigned To'=>'Asignado a',
'Billing Address'=>'Dirección (Factura)',
'Shipping Address'=>'Dirección (Envío)',
'Billing City'=>'Deleg./Mpio. (Factura)',
'Billing State'=>'Estado (Factura)',
'Billing Code'=>'Código Postal (Factura)',
'Billing Country'=>'País (Factura)',
'Billing Po Box'=>'Colonia (Factura)',
'Shipping Po Box'=>'Colonia (Envío)',
'Shipping City'=>'Deleg./Mpio. (Envío)',
'Shipping State'=>'Estado (Envío)',
'Shipping Code'=>'Código Postal (Envío)',
'Shipping Country'=>'País (Envío)',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Última Modificación',
'Description'=>'Descripción',
'Account Name'=>'Nombre de la Cuenta',
'Terms & Conditions'=>'Condiciones Generales',
//Quote Info
'LBL_QUOTE_INFORMATION'=>'Información de la Cotización',
'LBL_TERMS_INFORMATION'=>'Condiciones Generales',
'LBL_QUOTE'=>'Cotización:',

//Added during 4.2 release
'LBL_SUBJECT'=>'Referencia:',
'LBL_POTENTIAL_NAME'=>'Oportunidad:',
'LBL_ACCOUNT_NAME'=>'Nombre de la Cuenta:',
'LBL_QUOTE_STAGE'=>'Estado de la Cotización:',
'LBL_MY_TOP_QUOTE'=>'Mis Cotizaciones Pendientes',
//'Quote ID'=>'Id Cotización',
'Quote'=>'Cotización',

//Added for existing Picklist Entries

'Created'=>'Creado',
'Delivered'=>'Enviado',
'Reviewed'=>'Revisado',
'Accepted'=>'Aceptado',
'Rejected'=>'Rechazado',

'FedEx'=>'FedEx',
'UPS'=>'UPS',
'USPS'=>'Seur',
'DHL'=>'DHL',
'BlueDart'=>'Correos',
'Sales Tax'=>'Impuesto de Ventas',                 

//Added for Reports (5.0.4)
'Tax Type'=>'Impuesto',
'Discount Percent'=>'Descuento %',
'Discount Amount'=>'Descuento Importe',
'Terms & Conditions'=>'Condiciones Generales',
'Adjustment'=>'Ajustes',
'S&H Amount'=>'Importe Envío y Manejo',

//Added after 5.0.4 GA
'Quote No'=>'No Cotización',
'Add Service Contract'=>'Añadir Contrato de Servicio',
'Quotes ID'=>'Id Cotización',
);

?>
